# Generated by Django 4.2.6 on 2024-12-04 10:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oscarbot', '0009_user_created'),
    ]

    operations = [
        migrations.CreateModel(
            name='Group',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('t_id', models.CharField(default='', max_length=100, verbose_name='Telegram ID')),
                ('username', models.CharField(blank=True, default='', max_length=200, null=True, verbose_name='Username')),
                ('name', models.CharField(blank=True, default='', max_length=200, null=True, verbose_name='Имя')),
            ],
            options={
                'verbose_name': 'группа',
                'verbose_name_plural': 'группы',
            },
        ),
        migrations.AddField(
            model_name='user',
            name='groups',
            field=models.ManyToManyField(blank=True, to='oscarbot.group'),
        ),
    ]



from django.conf import settings


def route(path, func):
    return Route(path, func)


class Route:

    def __init__(self, pattern, func):
        self.pattern = pattern
        self.func = func
        self.params = dict()

    def __repr__(self):
        return self.pattern

    def check(self, path):
        if path:
            if any([i.isspace() for i in path]):
                path = self.refactoring_path(path)
            path_list = path.split('/')
            pattern_list = self.pattern.split('/')
            self.params = dict()

            if len(pattern_list) == len(path_list):
                for i in range(len(path_list)):
                    if len(pattern_list[i]) > 1:
                        if pattern_list[i][0] != '<':
                            if path_list[i] != pattern_list[i]:
                                return False
                        else:
                            self.params[pattern_list[i]] = path_list[i]
                return True
        return False

    def refactoring_path(self, path: str) -> str:
        """Refactoring path"""
        path_result = ''
        space = False
        for p in path:
            if p.isspace():
                if not space:
                    p = '/<'
                    space = True
                else:
                    p = '>/'
                    space = False
            path_result += p
        if space:
            path_result += '>/'
        return path_result

    def get_params(self):
        params = dict()
        for k, v in self.params.items():
            k = k.replace('<', '').replace('>', '')
            params[k] = v
        return params


class Router:
    path: str

    def __init__(self, path: str) -> None:
        self.path = path
        self.routes = self.__collect_all_routes()

    def __call__(self):
        func, arguments = self.__recognise()
        if func == arguments is None:
            print('Failed to load router')
            return False, False

        return func, arguments

    @staticmethod
    def __collect_all_routes() -> list:
        import importlib
        all_routes = []
        if len(settings.OSCARBOT_APPS) > 0:
            for app in settings.OSCARBOT_APPS:
                try:
                    module_name = f'{app}.router'
                    route_item = importlib.import_module(module_name)
                    all_routes.extend(route_item.routes)
                except ImportError as ex:
                    print(ex)
        return all_routes

    def __recognise(self):
        for route_item in self.routes:
            if route_item.check(self.path):
                return route_item.func, route_item.get_params()

        return None, None



from oscarbot.menu import Menu, Button
from oscarbot.messages import get_msg
from oscarbot.response import TGResponse


def start(_):
    return TGResponse(
        need_update=False
    )


def first_question(_):
    menu = Menu([
        Button("Да", callback="/diagnostic/"),
    ])
    return TGResponse(
        message='текст',
        file='https://s16.os-demo.tech/media/file.docx',
    )



from django.conf import settings
from django.core.management import BaseCommand
from oscarbot.bot import Bot
from oscarbot.models import Bot as TGBot


class Command(BaseCommand):

    def handle(self, *args, **options):
        """Create or update bot in database"""
        if getattr(settings, 'TELEGRAM_API_TOKEN', None):
            bot = Bot(token=settings.TELEGRAM_API_TOKEN)
            response = bot.get_me()
            status, result = response.get('ok'), response.get('result')
            if status and result:
                bot_id, is_bot = result.get('id'), result.get('is_bot')
                if is_bot:
                    first_name, last_name = result.get('first_name', ' '), result.get('last_name', ' ')
                    name = f'{first_name} {last_name}'.strip()
                    username = result.get('username')
                    TGBot.objects.update_or_create(
                        token=settings.TELEGRAM_API_TOKEN,
                        defaults={
                            't_id': bot_id,
                            'name': name,
                            'username': username,
                        }
                    )



import json
import time
import requests
from django.conf import settings
from django.core.management import BaseCommand

from oscarbot.bot_logger import log
from oscarbot.services import get_bot_model
from oscarbot.views import handle_content


class Command(BaseCommand):
    """Run Telegram bot in polling mode."""

    class BotData:
        """Fallback bot data."""
        token = None

    def handle(self, *args, **options):
        bot_model = get_bot_model()
        bot = bot_model.objects.first()
        if not bot:
            bot = self.BotData()
            bot.token = getattr(settings, 'TELEGRAM_API_TOKEN', None)
        if not bot.token:
            log.error('Bot token not found in DB or settings')
            return None
        offset = 0
        log.info('🚀 Bot polling started')
        try:
            while True:
                url = f'{settings.TELEGRAM_URL}{bot.token}/getUpdates'
                params = {
                    'offset': offset,
                    'timeout': 30,
                }
                response = requests.get(url, params=params, timeout=35)
                content = response.json()
                if not content.get('ok'):
                    raise ValueError('Invalid Telegram response')
                updates = content.get('result', [])
                if not updates:
                    time.sleep(.5)
                    continue
                for update in updates:
                    offset = update['update_id'] + 1
                    handle_content(bot.token, update)
        except KeyboardInterrupt:
            log.info('🛑 Bot polling stopped manually')
        except Exception as e:
            log.error(f'❌ Bot crashed: {e}')



from unittest.mock import patch

from django.test import TestCase

from oscarbot.models import User
from oscarbot.response import TGResponse
from oscarbot.tests.conf import mock_yaml_load


class ResponseTestCase(TestCase):

    def setUp(self):
        self.user = User.objects.create(t_id=1)

    @patch("yaml.load", mock_yaml_load)
    def test_add_message_to_response(self):
        """ Make response with auto got message text from yaml """
        def start(user):
            return TGResponse(need_update=False)

        called_function = start(self.user)

        self.assertEqual(called_function.message, '\' Hello! \'')



import requests
from django.conf import settings
from django.core.management import BaseCommand


class Command(BaseCommand):

    def handle(self, *args, **options):
        token = input('Enter your Telegram bot token: ')

        while True:
            msg = 'Enter webhook address'
            if hasattr(settings, 'BASE_URL'):
                msg += f' [or leave blank for "{settings.BASE_URL}"]: '
            else:
                msg += ': '

            base_url = input(msg)

            if base_url:
                if 'http:' in base_url:
                    base_url = base_url.replace('http:', 'https:')
                    self.stdout.write(
                        self.style.WARNING(
                            f'Address must be secure, changed to {base_url}'
                        )
                    )
                elif 'https' not in base_url:
                    base_url = 'https://' + base_url
                    self.stdout.write(
                        self.style.WARNING(
                            f'Full address will be set as {base_url}'
                        )
                    )

                if base_url[-1] != '/':
                    base_url += '/'

                break

            self.stdout.write(
                self.style.ERROR(
                    'Enter valid url or domain name'
                )
            )

        data = {
            'url': f'{base_url}api/bot{token}/'
        }
        response = requests.post(
            f'{settings.TELEGRAM_URL}{token}/setWebhook',
            json=data
        )
        if response.status_code == 200:
            self.stdout.write(
                self.style.SUCCESS(
                    response.json().get('description')
                )
            )
        else:
            self.stdout.write(
                self.style.ERROR(
                    response.json().get('description')
                )
            )



from unittest.mock import patch

from django.test import TestCase

from oscarbot.messages import get_msg
from oscarbot.tests.conf import mock_yaml_load


class MessagesTestCase(TestCase):
    DEFAULT_HELLO = '\' Hello! \''
    DONT_KNOW = '\'Sorry, i do not know this command\''

    @patch("yaml.load", mock_yaml_load)
    def test_get_msg_basic(self):
        """ Positive test for get message only by alias """
        got_msg = get_msg('start')

        self.assertEqual(got_msg, self.DEFAULT_HELLO)

    @patch("yaml.load", mock_yaml_load)
    def test_get_msg_with_args(self):
        """ Positive test for get message by alias and args """
        first_arg = 'test1'
        second_arg = 'test2'
        got_msg = get_msg('args', text_args=[first_arg, second_arg])

        self.assertEqual(got_msg, f'\' Hello! {first_arg}, {second_arg} \'')

    @patch("yaml.load", mock_yaml_load)
    def test_get_msg_not_found(self):
        """ Negative test for get message """
        got_msg = get_msg('some_alias')

        self.assertEqual(got_msg, self.DONT_KNOW)

    @patch("yaml.load", mock_yaml_load)
    def test_get_msg_by_func_name(self):
        """ Positive test for get message by func name """
        def start():
            return get_msg()

        result = start()

        self.assertEqual(result, self.DEFAULT_HELLO)



from django.core.management import BaseCommand

from oscarbot.messages import ResponseMessage


class Command(BaseCommand):
    help = "Help to work with text for messages"

    def add_arguments(self, parser):
        parser.add_argument(
            "--collect",
            action="store_true",
            help="Generate template file for save your messages text",
        )

        parser.add_argument(
            "--force",
            action="store_true",
            help="[Danger Zone] Hard replace messages file without backup",
        )

    def handle(self, *args, **options):
        """  """
        if options['collect']:
            ResponseMessage.collect()
        else:
            ResponseMessage.make_template(options['force'])




def mock_yaml_load(*args, **kwargs):
    return {
        'messages': {
            'start': '\' Hello! \'',
            'args': '\' Hello! {1}, {2} \''
        },
        'defaults': {
            'text_processor': '\'  \'',
            'dont_know': '\'Sorry, i do not know this command\'',
            'voice_processor': '\'  \''
        }
    }




import json
import os
import random

import requests
from django.conf import settings


class Bot:
    token = None
    menu = None
    api_url = settings.TELEGRAM_URL

    def __init__(self, token):
        self.token = token

    def send_message(self, chat_id, message, photo=None, video=None, file=None, media_group=None, has_spoiler=False,
                     media_group_type='photo', is_silent=False, is_background=False, reply_to_msg_id=None,
                     parse_mode='HTML', reply_keyboard=None, protect_content=False, disable_web_page_preview=False,
                     is_delete_message=False, message_delete=None):
        """
        @param file:
        @param disable_web_page_preview:
        @param chat_id:
        @param message:
        @param photo:
        @param video:
        @param media_group:
        @param has_spoiler:
        @param media_group_type:
        @param is_silent:
        @param is_background:
        @param reply_to_msg_id:
        @param parse_mode:
        @param reply_keyboard:
        @param protect_content:
        @param is_delete_message:
        @param message_delete:
        @return: reply message json
        :param line_button:
        """
        params = {
            'chat_id': chat_id,
            'text': message,
            'parse_mode': parse_mode,
            'protect_content': protect_content
        }
        if reply_keyboard is not None:
            params['reply_markup'] = reply_keyboard
        if is_silent:
            params['silent'] = True
            params['disable_notification'] = True
        if is_background:
            params['background'] = True
        if reply_to_msg_id:
            params['reply_to_msg_id'] = reply_to_msg_id

        params['disable_web_page_preview'] = disable_web_page_preview
        value = random.randint(1, 10 ** 100)
        if photo:
            if 'https://' in photo:
                params['photo'] = f'{photo}?random={value}&random={value}'
            else:
                params['photo'] = f'{settings.BASE_URL}{settings.MEDIA_URL}{photo}?random={value}&random={value}'
            params['caption'] = params['text']
            result = requests.post(self.api_url + self.token + "/sendPhoto", data=params)
        elif video:
            if video.startswith('https://'):
                params['video'] = f'{video}?random={value}&random={value}'
            else:
                params['video'] = f'{settings.BASE_URL}{settings.MEDIA_URL}{video}?random={value}&random={value}'
            params['caption'] = params['text']
            result = requests.post(self.api_url + self.token + "/sendVideo", data=params)
        elif file:
            if file.startswith('https://'):
                params['document'] = f'{file}?random={value}&random={value}'
            else:
                params['document'] = f'{settings.BASE_URL}{settings.MEDIA_URL}{file}?random={value}&random={value}'
            params['caption'] = params['text']
            result = requests.post(self.api_url + self.token + "/sendDocument", data=params)
        elif media_group:
            data = []
            for file in media_group:
                media = f"{file['media']}?random={value}&random={value}"
                if not media.startswith('https://'):
                    media = f'{settings.BASE_URL}{settings.MEDIA_URL}{media}?random={value}&random={value}'
                media_data = {
                    'type': media_group_type,
                    'parse_mode': parse_mode,
                    'has_spoiler': has_spoiler,
                    'media': media,
                }
                if 'caption' in file:
                    media_data['caption'] = file['caption']
                data.append(media_data)
            params['media'] = json.dumps(data)
            result = requests.post(self.api_url + self.token + "/sendMediaGroup", data=params)
        else:
            result = requests.post(self.api_url + self.token + "/sendMessage", data=params)
        if is_delete_message:
            self.delete_message(chat_id, message_delete)
        content = result.content.decode('utf-8')
        return content

    def send_photo(self, chat_id, photo_url):
        """
        @param chat_id:
        @param photo_url:
        @return: reply message json
        """
        params = {'chat_id': chat_id, 'photo': photo_url, 'parse_mode': 'Markdown'}
        result = requests.post(self.api_url + self.token + "/sendPhoto", data=params)
        content = result.content.decode('utf-8')
        return content

    def send_video(self, chat_id, video_url):
        params = {
            'chat_id': chat_id,
            'video_note': video_url,
            'parse_mode': 'Markdown',
            'length': 100
        }
        result = requests.post(self.api_url + self.token + "/sendVideoNote", data=params)
        content = result.content.decode('utf-8')
        return content

    def send_photos(self, chat_id, photos):
        photo_group = []
        for photo in photos:
            photo_group.append(
                {
                    'type': 'photo',
                    'media': photo
                }
            )
        params = {'chat_id': chat_id, 'media': json.dumps(photo_group)}
        result = requests.post(self.api_url + self.token + "/sendMediaGroup", data=params)
        content = result.content.decode('utf-8')
        return content

    def update_message(self, chat_id, message, message_id, is_silent=False, is_background=False, reply_to_msg_id=None,
                       parse_mode='HTML', reply_keyboard=None, is_delete_message=False, message_delete=None, **_):
        params = {
            'chat_id': chat_id,
            'message_id': message_id,
            'text': message,
            'parse_mode': parse_mode,
            'protect_content': True
        }
        if reply_keyboard is not None:
            params['reply_markup'] = reply_keyboard
        if is_silent:
            params['silent'] = True
            params['disable_notification'] = True
        if is_background:
            params['background'] = True
        if reply_to_msg_id:
            params['reply_to_msg_id'] = reply_to_msg_id

        params['disable_web_page_preview'] = True
        result = requests.post(self.api_url + self.token + "/editMessageText", data=params)
        content = result.content.decode('utf-8')
        if is_delete_message:
            self.delete_message(chat_id, message_delete)
        return content

    def delete_message(self, chat_id, message_id):
        params = {'chat_id': chat_id, 'message_id': message_id}
        response = requests.post(self.api_url + self.token + '/deleteMessage', data=params)
        return response

    def get_file(self, file_id):
        result = requests.get(self.api_url + self.token + f'/getFile?file_id={file_id}')
        json_result = result.json()
        if json_result['ok']:
            file_path = json_result['result']['file_path']

            return f"https://api.telegram.org/file/bot{self.token}/{file_path}"
        return None

    def get_user_photo(self, t_id):
        result = requests.get(self.api_url + self.token + '/getUserProfilePhotos', data={'user_id': t_id})
        json_result = result.json()
        if json_result['ok']:
            photos = json_result['result']['photos']
            if len(photos) > 0:
                smallest_photo = photos[0][0]['file_id']
                result = requests.get(self.api_url + self.token + f'/getFile?file_id={smallest_photo}')
                json_result = result.json()
                if json_result['ok']:
                    photo_path = json_result['result']['file_path']
                    result = requests.get(f"https://api.telegram.org/file/bot{self.token}/{photo_path}")
                    media_file = f'users/{t_id}.jpg'
                    with open(os.path.join(settings.BASE_DIR, f'media/{media_file}'), 'wb') as f:
                        f.write(result.content)
                    return media_file
        return None

    def answer_callback_query(self, callback_query_id, text, url, show_alert, cache_time):
        """Answer callback query."""
        params = {
            'callback_query_id': callback_query_id,
            'show_alert': show_alert,
            'cache_time': cache_time,
        }
        if text:
            params['text'] = text
        if url:
            params['url'] = url
        result = requests.post(self.api_url + self.token + '/answerCallbackQuery', data=params)
        return result.content

    def get_me(self):
        """Get me."""
        result = requests.post(self.api_url + self.token + '/getMe')
        return result.json()
